#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-cabal-fmt-z-version-interval
version:              0.1.7
package-name:         cabal-fmt
lib-name:             version-interval
id:                   cabal-fmt-0.1.7-5aAyVPXbdck43Ij1rNgieb-version-interval
key:                  cabal-fmt-0.1.7-5aAyVPXbdck43Ij1rNgieb-version-interval
license:              GPL-3.0-or-later AND BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Format .cabal files
description:
    Format @.cabal@ files preserving the original field ordering, and comments.

    Tuned for Oleg'\''s preference, but has some knobs still.

category:             Development
abi:                  be4521b05f1f42dc0b89af5bc7c7cfa7
exposed-modules:      VersionInterval
import-dirs:          /usr/lib/ghc-9.6.6/site-local/cabal-fmt-0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cabal-fmt-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cabal-fmt-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cabal-fmt
hs-libraries:         HScabal-fmt-0.1.7-5aAyVPXbdck43Ij1rNgieb-version-interval
depends:              Cabal-syntax-3.10.3.0 base-4.18.2.1
haddock-interfaces:   /usr/share/doc/cabal-fmt/html/cabal-fmt.haddock
haddock-html:         /usr/share/doc/cabal-fmt/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 z-cabal-fmt-z-cabal-fmt-internal
version:              0.1.7
package-name:         cabal-fmt
lib-name:             cabal-fmt-internal
id:                   cabal-fmt-0.1.7-EsmWJtTAAQAHjTn0112vh4-cabal-fmt-internal
key:                  cabal-fmt-0.1.7-EsmWJtTAAQAHjTn0112vh4-cabal-fmt-internal
license:              GPL-3.0-or-later AND BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
synopsis:             Format .cabal files
description:
    Format @.cabal@ files preserving the original field ordering, and comments.

    Tuned for Oleg'\''s preference, but has some knobs still.

category:             Development
abi:                  a2ed69222c0b0b53e71989a1c70891f4
exposed-modules:
    CabalFmt CabalFmt.Comments CabalFmt.Error CabalFmt.Fields
    CabalFmt.Fields.BuildDepends CabalFmt.Fields.Extensions
    CabalFmt.Fields.Modules CabalFmt.Fields.SourceFiles
    CabalFmt.Fields.TestedWith CabalFmt.Glob CabalFmt.Monad
    CabalFmt.Options CabalFmt.Parser CabalFmt.Pragma CabalFmt.Prelude
    CabalFmt.Refactoring CabalFmt.Refactoring.ExpandExposedModules
    CabalFmt.Refactoring.Fragments CabalFmt.Refactoring.GlobFiles
    CabalFmt.Refactoring.Type

import-dirs:          /usr/lib/ghc-9.6.6/site-local/cabal-fmt-0.1.7
library-dirs:         /usr/lib/ghc-9.6.6/site-local/cabal-fmt-0.1.7
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/cabal-fmt-0.1.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/cabal-fmt
hs-libraries:         HScabal-fmt-0.1.7-EsmWJtTAAQAHjTn0112vh4-cabal-fmt-internal
depends:
    Cabal-syntax-3.10.3.0 base-4.18.2.1 bytestring-0.11.5.3
    cabal-fmt-0.1.7-5aAyVPXbdck43Ij1rNgieb-version-interval
    containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1 mtl-2.3.1
    parsec-3.1.16.1 pretty-1.1.3.6

haddock-interfaces:   /usr/share/doc/cabal-fmt/html/cabal-fmt.haddock
haddock-html:         /usr/share/doc/cabal-fmt/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

